@@ -20,7 +20,7 @@ hfox = janda.Asmhentai()
 async def get_asm(id: int = choose().asmhentai):
     initial = time.time()
     data = await hfox.get(id)
-    parser = json.loads(data)
+    parser = janda.resolve(data)
     title = parser["title"]
     title = re.sub(r"[^\w\s]", "", title)
     number = parser["id"]
