@@ -20,7 +20,7 @@ nh = janda.Nhentai()
 async def get_nh(id: int = choose().nhentai):
     initial = time.time()
     data = await nh.get(id)
-    parser = json.loads(data)
+    parser = janda.resolve(data)
 
     title = parser["details"]["title"]["pretty"]
     title = re.sub(r"[^\w\s]", "", title)
