@@ -21,7 +21,7 @@ simply = janda.SimplyHentai()
 async def get_sim(id: str = choose().simply):
     initial = time.time()
     data = await simply.get(id)
-    parser = json.loads(data)
+    parser = janda.resolve(data)
 
     title = parser["title"]
     title = re.sub(r"[^\w\s]", "", title)
